# TODO check that no license information gets lost
{ fetchurl, bash, stdenv, python, cmake, vim, vimUtils, perl, ruby, unzip,
  which, fetchgit, fetchFromGitHub, fetchhg, fetchzip, llvmPackages, zip,
  vim_configurable, vimPlugins, xkb_switch, git
}:

let

inherit (vimUtils.override {inherit vim;}) rtpPath addRtp buildVimPlugin
  buildVimPluginFrom2Nix vimHelpTags;
in

# This attrs contains two sections:
# The first contains plugins added manually, the second contains plugins
# generated by call nix#ExportPluginsForNix.
# Documentation & usage see vim-utils.nix.
# attribute names should be the same as used by vim-pi to make dependency
# resolution work
rec {

  ### section I: manually mantained plugins

  a = buildVimPlugin {
    name = "a-git-2010-11-06";
    src = fetchgit {
      url = "https://github.com/vim-scripts/a.vim.git";
      rev = "2cbe946206ec622d9d8cf2c99317f204c4d41885";
      sha256 = "ca0982873ed81e7f6545a6623b735104c574fe580d5f21b0aa3dc1557edac240";
     };
    meta = {
      homepage = https://github.com/vim-scripts/a.vim;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  airline = vim-airline;

  align = buildVimPlugin {
    name = "align-git-2012-08-07";
    src = fetchgit {
      url = "https://github.com/vim-scripts/align.git";
      rev = "787662fe90cd057942bc5b682fd70c87e1a9dd77";
      sha256 = "f7b5764357370f03546556bd45558837f3790b0e86afadb63cd04d714a668a29";
     };
    meta = {
      homepage = https://github.com/vim-scripts/align;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  alternative = a; # backwards compat, added 2014-10-21

  calendar = buildVimPlugin {
    name = "calendar-git-2015-03-19";
    src = fetchgit {
      url = "https://github.com/itchyny/calendar.vim.git";
      rev = "a1b9d1a11e301a25bc48350da833469ef8bb6c9f";
      sha256 = "a3a8da7890c5eedba72e2def86760b79092b3b5cf2ca3999deda5fa8eddecd49";
    };
    meta = {
      homepage = https://github.com/itchyny/calendar.vim; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  command-t = buildVimPlugin rec {
    name = "command-t-git-2015-01-12";
    src = fetchgit {
      url = "https://github.com/wincent/Command-T";
      rev = "13760a725779b65fa0f2ebef51806f3c05a52550";
      sha256 = "0cb284w1m8sxcc8ph64pm0cvqslpixss593a1ffnx9c09g6d7m8w";
    };
    buildInputs = [ perl ruby ];
    buildPhase = ''
      pushd ruby/command-t
      ruby extconf.rb
      make
      popd
    '';
  };

  command_T = command-t; # backwards compat, added 2014-10-18

  easymotion = buildVimPlugin {
    name = "easymotion-git-2015-02-24";
    src = fetchgit {
      url = "https://github.com/lokaltog/vim-easymotion.git";
      rev = "8acdfc60e58bb0600ded42a4f752bec6e3b6d882";
      sha256 = "1177d1c06a16fe7c1e681a729d158a6cacf3fed9c14bd8c4ece35a069f21dc07";
    };
    meta = {
      homepage = https://github.com/lokaltog/vim-easymotion; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };
  
  eighties = buildVimPlugin {
    name = "eighties-git-2015-02-12";
    src = fetchgit {
      url = "https://github.com/justincampbell/vim-eighties";
      rev = "5d0ebf5424adb8017bec049de0cd51f6fa427281";
      sha256 = "b4216c805e54f923efcbd8d914f97883f135c989f33e87d2eee69b488b57e747";
    };
    buildPhase = ":";
    meta = with stdenv.lib; {
      description = "Automatically resizes your windows to 80 characters";
      homepage    = https://github.com/justincampbell/vim-eighties;
      license     = licenses.publicDomain;
      maintainers = with maintainers; [ lovek323 ];
      platforms   = platforms.unix;
    };
  };


  gitgutter = vim-gitgutter;

  golang = buildVimPlugin {
    name = "golang-git-2014-08-06";
    src = fetchgit {
      url = "https://github.com/jnwhiteh/vim-golang.git";
      rev = "e6d0c6a72a66af2674b96233c4747661e0f47a8c";
      sha256 = "1231a2eff780dbff4f885fcb4f656f7dd70597e1037ca800470de03bf0c5e7af";
     };
    meta = {
      homepage = https://github.com/jnwhiteh/vim-golang;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  hardtime = buildVimPlugin {
    name = "hardtime-git-2014-10-21";
    src = fetchgit {
      url = "https://github.com/takac/vim-hardtime.git";
      rev = "b401c72528d1c23e4cc9bc9585fda4361d0199bf";
      sha256 = "65e4bda7531076147fc46f496c8e56c740d1fcf8fe85c18cb2d2070d0c3803cd";
     };
    meta = {
      homepage = https://github.com/takac/vim-hardtime;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  haskellconceal = buildVimPlugin {
    name = "haskellconceal-git-2014-08-07";
    src = fetchgit {
      url = "https://github.com/twinside/vim-haskellconceal.git";
      rev = "1d85e8f10b675d38ec117368ec8032f486c27f98";
      sha256 = "8ae762939ea435333031a094f3c63e6edd534ac849f0008fa0440440f1f2f633";
     };
    meta = {
      homepage = https://github.com/twinside/vim-haskellconceal;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  haskellConceal = haskellconceal; # backwards compat, added 2014-10-18

  hasksyn = buildVimPlugin {
    name = "hasksyn-git-2014-09-03";
    src = fetchgit {
      url = "https://github.com/travitch/hasksyn.git";
      rev = "c434040bf13a17ca20a551223021b3ace7e453b9";
      sha256 = "b1a735928aeca7011b83133959d59b9c95ab8535fd00ce9968fae4c3b1381931";
     };
    meta = {
      homepage = https://github.com/travitch/hasksyn;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  hdevtools = buildVimPlugin {
    name = "hdevtools-git-2012-12-29";
    src = fetchgit {
      url = "https://github.com/bitc/vim-hdevtools.git";
      rev = "474947c52ff9c93dd36f3c49de90bd9a78f0baa1";
      sha256 = "bf5f096b665c51ce611c6c1bfddc3267c4b2f94af84b04482b07272a6a5a92f3";
     };
    meta = {
      homepage = https://github.com/bitc/vim-hdevtools;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  hier = buildVimPlugin {
    name = "hier-git-2011-08-27";
    src = fetchgit {
      url = "https://github.com/jceb/vim-hier.git";
      rev = "0b8c365263551a67404ebd7e528c55e17c1d3de7";
      sha256 = "f62836545abfe379f9c5410da28409947407cd282ef784b2db89aed0756a1785";
     };
    buildInputs = [ vim ];
    meta = {
      homepage = https://github.com/jceb/vim-hier;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  idris-vim = buildVimPlugin {
    name = "idris-vim-git-2014-12-29";
    src = fetchgit {
      url = "https://github.com/idris-hackers/idris-vim.git";
      rev = "6bdb44b85406b75e3b3a4fa265deab1dbe8c6ff1";
      sha256 = "87677f3aa81f15dbaf4337f709952fd47c9fa28e8086033f2cfbd5b1f256e5ff";
    };
    meta = {
      homepage = https://github.com/idris-hackers/idris-vim; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  ipython = buildVimPlugin {
    name = "ipython-git-2015-01-12";
    src = fetchgit {
      url = "https://github.com/ivanov/vim-ipython.git";
      rev = "a47d92b371588a81f8501c66604d79e2827c60a8";
      sha256 = "7cf2dbed5b404164199d4784331b21d90d371275b1d324298cde9eeda3c4eb53";
    };
    meta = {
      homepage = https://github.com/ivanov/vim-ipython; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  latex-box = buildVimPlugin {
    name = "latex-box-git-2015-03-05";
    src = fetchgit {
      url = "https://github.com/latex-box-team/latex-box.git";
      rev = "0992511ad9b250cbe53bccbec3b0cb24feca64ec";
      sha256 = "8e73020a4ad275dfb8887bfc6a85c8aa059a081feefb680b2fd7c85267137440";
    };
    meta = {
      homepage = https://github.com/latex-box-team/latex-box; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  lushtags = buildVimPlugin {
    name = "lushtags-git-2013-12-27";
    src = fetchgit {
      url = "https://github.com/bitc/lushtags.git";
      rev = "429fab3b748ae04ee5de0cbf75d947f15441e798";
      sha256 = "5170019fbe64b15be30a0ba82e6b01364d115ccad6ef690a6df86f73af22a0a7";
     };
    meta = {
      homepage = https://github.com/bitc/lushtags;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  neco-ghc = buildVimPlugin {
    name = "neco-ghc-git-2015-03-21";
    src = fetchgit {
      url = "https://github.com/eagletmt/neco-ghc.git";
      rev = "7d2c360736679064986925873b8d1e2b1978d9f8";
      sha256 = "3c4d1b00c79953e56379792a64df036075a456cb10a7b891e1691d04c9f15310";
    };
    meta = {
      homepage = https://github.com/eagletmt/neco-ghc; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  necoGhc = neco-ghc; # backwards compat, added 2014-10-18

  neocomplete = buildVimPlugin {
    name = "neocomplete-git-2015-03-24";
    src = fetchgit {
      url = "https://github.com/Shougo/neocomplete.vim.git";
      rev = "1ef1c33cfdcae43d8b3c6381c4f54f0e93a17287";
      sha256 = "5c61629c30906aacc00924ab5aaad720aba0011df348ea8835b6aaa53199550a";
    };
    meta = {
      homepage = https://github.com/Shougo/neocomplete.vim; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  neosnippet = buildVimPlugin {
    name = "neosnippet-git-2015-01-19";
    src = fetchgit {
      url = "https://github.com/Shougo/neosnippet.vim.git";
      rev = "044c9cb8ca46a5e27eec37198990c26fe707b02a";
      sha256 = "c448fac34e432a496ec1d76e07b478b27e66e6e4ec99c1b3923e66c781b74fc8";
    };
    meta = {
      homepage = https://github.com/Shougo/neosnippet.vim; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  neosnippet-snippets = buildVimPlugin {
    name = "neosnippet-snippets-git-2015-03-25";
    src = fetchgit {
      url = "https://github.com/Shougo/neosnippet-snippets.git";
      rev = "dfa436157c9e72f16f0f0d088fa181b37e226c2f";
      sha256 = "00a65d1f6a1309acef42c0ca70f333ab355db521319c14db8247be38d28da730";
    };
    meta = {
      homepage = https://github.com/Shougo/neosnippet-snippets; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };


  nerdcommenter = The_NERD_Commenter;

  quickrun = buildVimPlugin {
    name = "quickrun-git-2015-03-26";
    src = fetchgit {
      url = "https://github.com/thinca/vim-quickrun.git";
      rev = "2d03b3a7405da0e95ff7f6f617843ba9f536395f";
      sha256 = "803e902a083b79c70ea3f826a89864b8879897cd36a655d9e789a0d651127eb3";
     };
    meta = {
      homepage = https://github.com/thinca/vim-quickrun;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  racer = buildVimPlugin {
    name = "racer-git-2015-03-23";
    src = fetchgit {
      url = "https://github.com/phildawes/racer";
      rev = "c6f557bfd9a22d45476651fa95f7d8415ed897a8";
      sha256 = "697d92e0acbb3a8c1d691eaebc008bec422060df10e3c4cf6fad448b30391852";
    };
    buildPhase = ''
      find . -type f -not -name 'racer.vim' -exec rm -rf {} \;
      rm -rf editors images src
    '';
    meta = {
      homepage = https://github.com/phildawes/racer;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  shabadou = buildVimPlugin {
    name = "shabadou-git-2014-07-27";
    src = fetchgit {
      url = "https://github.com/osyo-manga/shabadou.vim.git";
      rev = "c5af30bb0c028d53cfd89e00cab636c844034a9a";
      sha256 = "392efa8a5e725219e478b571d9a30ddba88d47662467ed3123a168e8b55c4de6";
     };
    meta = {
      homepage = https://github.com/osyo-manga/shabadou.vim;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  stylish-haskell = buildVimPlugin {
    name = "stylish-haskell-git-2014-07-14";
    src = fetchgit {
      url = "https://github.com/nbouscal/vim-stylish-haskell.git";
      rev = "453fd203aee3d7305ea8e4088ff53bd1f5933d75";
      sha256 = "c0e5010e1e8e56b179ce500387afb569f051c45b37ce92feb4350f293df96a8c";
     };
    meta = {
      homepage = https://github.com/nbouscal/vim-stylish-haskell;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  stylishHaskell = stylish-haskell; # backwards compat, added 2014-10-18

  tabmerge = buildVimPlugin {
    name = "tabmerge-git-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/tabmerge.git";
      rev = "074e5f06f26e7108a0570071a0f938a821768c06";
      sha256 = "b84501b0fc5cd51bbb58f12f4c2b3a7c97b03fe2a76446b56a2c111bd4f7335f";
     };
    meta = {
      homepage = https://github.com/vim-scripts/tabmerge;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  taglist = buildVimPlugin {
    name = "taglist-4.6";
    meta = with stdenv.lib; {
      description = "Source code browser plugin";
      homepage    = "http://www.vim.org/scripts/script.php?script_id=273";
      license     = licenses.gpl3;
      maintainers = with maintainers; [ lovek323 ];
      platforms   = platforms.unix;
    };
    src = fetchurl {
      url    = "http://www.vim.org/scripts/download_script.php?src_id=19574";
      name   = "taglist_46.zip";
      sha256 = "18cbv462vwg7vip2p99qlahm99hswav96cj4ki227kyi05q2lkjj";
    };
    setSourceRoot = ''
      export sourceRoot=taglist
      mkdir taglist
      mv doc taglist
      mv plugin taglist
    '';
    buildInputs = [ unzip ];
  };

  thumbnail = buildVimPlugin {
    name = "thumbnail-git-2015-03-15";
    src = fetchgit {
      url = "https://github.com/itchyny/thumbnail.vim.git";
      rev = "19bd717307a8d0986a4a77116f47168fbe11e178";
      sha256 = "c8c100e1b0ee9c75fc3b6db00b68c47d91bcca8979f6de046aade43fd09e3882";
     };
    meta = {
      homepage = https://github.com/itchyny/thumbnail.vim;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  tmux-navigator = buildVimPlugin {
    name = "tmux-navigator-git-2015-03-16";
    src = fetchgit {
      url = "https://github.com/christoomey/vim-tmux-navigator.git";
      rev = "928a52fbda90ec70b2eb6edaf570654df4521af0";
      sha256 = "6f6912960245664146ead711886aad216b74f4c6b1feec975cab199114afb13c";
     };
    meta = {
      homepage = https://github.com/christoomey/vim-tmux-navigator;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  tmuxNavigator = tmux-navigator; # backwards compat, added 2014-10-18

  tslime = buildVimPlugin {
    name = "tslime-git-2015-02-10";
    src = fetchgit {
      url = "https://github.com/jgdavey/tslime.vim.git";
      rev = "71ec1cbe8f9ead9805f8e0c3b76c590aeb5ed0b7";
      sha256 = "81f45f579dcc239ce0b9689044d0e92969f7538759ab0cd88596c7a010d8730b";
     };
    meta = {
      homepage = https://github.com/jgdavey/tslime.vim;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  vimproc = buildVimPlugin {
    name = "vimproc-git-2015-02-23";
    src = fetchgit {
      url = "https://github.com/shougo/vimproc.vim.git";
      rev = "0f68bcd93399ecbcde3eaa4efd09107314c9bdee";
      sha256 = "850cb6d347f4c353782c48533f2dc6e3150a3982dc71efbd5f6b0a921264f939";
    };
    buildInputs = [ which ];

    buildPhase = ''
      sed -i 's/vimproc_mac\.so/vimproc_unix\.so/' autoload/vimproc.vim
      make -f make_unix.mak
    '';

    meta = {
      homepage = https://github.com/shougo/vimproc.vim;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  vimshell = buildVimPlugin rec {
    name = "vimshell-git-2015-03-24";
    src = fetchgit {
      url = "https://github.com/Shougo/vimshell.vim";
      rev = "41d3ad325852e80588ab57c64433fa338789d6ac";
      sha256 = "bf76ee252a3cbb121013ce10547cee7d31a64d10c46687ddfaa988e7c5baf095";
    };
    meta = with stdenv.lib; {
      description = "An extreme shell that doesn't depend on external shells and is written completely in Vim script";
      homepage    = https://github.com/Shougo/vimshell.vim;
      repositories.git = https://github.com/Shougo/vimshell.vim.git;
      license     = licenses.gpl3;
      maintainers = with maintainers; [ lovek323 ];
      platforms   = platforms.unix;
    };
    buildInputs = [ vimproc ];
    preBuild = ''
      sed -ie '1 i\
      set runtimepath+=${vimproc}/${rtpPath}/vimproc\
      ' autoload/vimshell.vim
    '';
  };

  wakatime = buildVimPlugin {
    name = "wakatime-3.0.9";

    src = fetchFromGitHub {
      sha256 = "0qq2h5ysbixypz1ga5j3yrh8sd5h1npqkd59dpl5c1mvjlc30fpk";
      rev = "f5848439ffdf63db3859f692df1d8fa64b1b3edf";
      repo = "vim-wakatime";
      owner = "wakatime";
    };

    meta = with stdenv.lib; {
      description = "Analytics about your programming";
      homepage = https://wakatime.com;
      license = with licenses; bsd3;
      platforms = with platforms; linux;
      maintainers = with maintainers; [ nckx ];
    };

    buildInputs = [ python ];
  };

  watchdogs = buildVimPlugin {
    name = "watchdogs-git-2015-03-20";
    src = fetchgit {
      url = "https://github.com/osyo-manga/vim-watchdogs.git";
      rev = "01ba53074fd3bedd81f5aed2dcc4fec092f62ba9";
      sha256 = "7b363779a0b035a0aaec025653a29e2f4dbd9e1518a34a6e993c43e8ec810d57";
     };
    meta = {
      homepage = https://github.com/osyo-manga/vim-watchdogs;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  xdebug = buildVimPlugin {
    name = "xdebug-git-2012-08-15";
    src = fetchgit {
      url = "https://github.com/joonty/vim-xdebug.git";
      rev = "a4980fa65f7f159780593ee37c178281691ba2c4";
      sha256 = "1ccb0e63eaf68548feb1c37b09c07c84b6bea9b350c4257549f091aa414601e2";
     };
    postInstall = false;
    meta = {
      homepage = https://github.com/joonty/vim-xdebug;
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  xkbswitch = buildVimPlugin {
    name = "xkbswitch-git-2015-01-18";
    src = fetchgit {
      url = "https://github.com/lyokha/vim-xkbswitch.git";
      rev = "932765d8a45b0c8b994b920505b8f10cc7e8cad0";
      sha256 = "20e1f7196b65d98687a27c8a3f2d0847701890a0818dfcfec13f24a3151b0e73";
     };
    buildInputs = [ xkb_switch ];
    meta = {
      homepage = https://github.com/lyokha/vim-xkbswitch; 
      maintainers = [ stdenv.lib.maintainers.jagajaga ];
    };
  };

  YouCompleteMe = buildVimPlugin {
    src = fetchgit {
      rev = "2f8109020644ad28e5cd795c29bc1150f87b3cb4";
      url = "https://github.com/Valloric/YouCompleteMe";
      sha256 = "15d3dhxan602qxz2wixjf4pjrf210qwa51ckzyjyh5kqak9lx8pi";
     };
    name = "youcompleteme-2015-03-27";

    buildInputs = [
      python cmake
      llvmPackages.clang-unwrapped llvmPackages.llvm
    ];

    configurePhase = ":";

    buildPhase = ''
      patchShebangs .

      target=$out/${rtpPath}/youcompleteme
      mkdir -p $target
      cp -a ./ $target

      mkdir $target/build
      cd $target/build
      cmake -G "Unix Makefiles" . $target/third_party/ycmd/cpp -DPYTHON_LIBRARIES:PATH=${python}/lib/libpython2.7.so -DPYTHON_INCLUDE_DIR:PATH=${python}/include/python2.7 -DUSE_CLANG_COMPLETER=ON -DUSE_SYSTEM_LIBCLANG=ON
      make ycm_support_libs -j''${NIX_BUILD_CORES} -l''${NIX_BUILD_CORES}}
      ${bash}/bin/bash $target/install.sh --clang-completer --system-libclang

      ${vimHelpTags}
      vimHelpTags $target
    '';

    # TODO: implement proper install phase rather than keeping everything in store
    # TODO: support llvm based C completion, See README of git repository
    installPhase = ":";

    meta = {
      description = "Fastest non utf-8 aware word and C completion engine for Vim";
      homepage = http://github.com/Valloric/YouCompleteMe;
      license = stdenv.lib.licenses.gpl3;
      maintainers = with stdenv.lib.maintainers; [marcweber jagajaga];
      platforms = stdenv.lib.platforms.linux;
    };
  };

  youcompleteme = YouCompleteMe;

  YUNOcommit = buildVimPlugin {
    name = "YUNOcommit";
    src = fetchgit {
      url = "https://github.com/esneider/YUNOcommit.vim";
      rev = "981082055a73ef076d7e27477874d2303153a448";
      sha256 = "4bfd80720c353884e5c373b5457397a63e5e2e4ab4a97d6ce86c1740ac3b4c56";
    
    };
    dependencies = [];
  };


  ### section II: automatically generated plugin derivations
  # Update with vimUtils.vimPlugins.pluginnames2Nix command

  # This is not a plugin, it provides bin/vim-open-buffer-with-plugins-derivations
  # which recreates this the following derivations based on ./vim-plugin-names
  pluginnames2nix = vimUtils.pluginnames2Nix {
    name = "vim-plugin-names-to-nix";
    namefiles = [./vim-plugin-names];
  };

  # aliasess
  tabular = Tabular;
  tagbar = Tagbar;
  coffee-script = vim-coffee-script;
  coffeeScript = coffee-script; # backwards compat, added 2014-10-18
  colors-solarized = Solarized;
  colorsamplerpack = Colour_Sampler_Pack;
  easy-align = vim-easy-align;
  ghc-mod-vim = ghcmod;
  gist-vim = Gist;
  gundo = Gundo;
  hoogle = Hoogle;
  latex-live-preview = vim-latex-live-preview;
  nerdtree = The_NERD_tree;
  signature = vim-signature;
  supertab = Supertab;
  syntastic = Syntastic;
  webapi-vim = WebAPI;
  yankring = YankRing;
  "sourcemap.vim" = sourcemap;


  ### The following derivations are generated by nix#ExportPluginsForNix


  "Colour_Sampler_Pack" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Colour_Sampler_Pack";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=18915";
      name = "ColorSamplerPack.zip";
      sha256 = "1wsrb3vpqn9fncnalfpvc8r92wk1mcskm4shb3s2h9x5dyihf2rd";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=625";
    };


  };
  "Gist" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Gist-2015-03-25";
    src = fetchgit {
      url = "git://github.com/mattn/gist-vim";
      rev = "22eeb3a72f116818dec0e2f9fe3ea46443141b95";
      sha256 = "9ecaa593267958c5860d6e34be5fc1e3280da5265a1fb35bdb2904163049325f";
    };
    dependencies = [];

  };
  "Gundo" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Gundo";
    src = fetchhg {
      url = "https://bitbucket.org/sjl/gundo.vim";
      rev = "eb9fc8676b89";
      sha256 = "05lcxrd9ibfi02ja4jvl5y5pp884b8kh9aarw045b0mlldygv6cp";
    };
    dependencies = [];

  };
  "Hoogle" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Hoogle-2013-11-26";
    src = fetchgit {
      url = "git://github.com/Twinside/vim-hoogle";
      rev = "81f28318b0d4174984c33df99db7752891c5c4e9";
      sha256 = "0f96f3badb6218cac87d0f7027ff032ecc74f08ad3ada542898278ce11cbd5a0";
    };
    dependencies = [];

  };
  "Solarized" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Solarized-2011-05-09";
    src = fetchgit {
      url = "git://github.com/altercation/vim-colors-solarized";
      rev = "528a59f26d12278698bb946f8fb82a63711eec21";
      sha256 = "a1b2ef696eee94dafa76431c31ee260acdd13a7cf87939f27eca431d5aa5a315";
    };
    dependencies = [];

  };
  "Supertab" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Supertab-2015-02-15";
    src = fetchgit {
      url = "git://github.com/ervandew/supertab";
      rev = "c8bfeceb1fc92ad58f2ae6967cbfcd6fbcb0d6e7";
      sha256 = "e9e4054c683435b36adf87bebb4895c06a7e85130a807d8c9307588d4744b04b";
    };
    dependencies = [];

  };
  "Syntastic" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Syntastic-2015-03-25";
    src = fetchgit {
      url = "git://github.com/scrooloose/syntastic";
      rev = "dac07db61758590c71d655ed5403181af4e845a2";
      sha256 = "96ae43056b79a50c34272f483c5c7a3cf55f5aa8699b319fe9ed5f7ba12ed0d7";
    };
    dependencies = [];

  };
  "Tabular" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tabular-2013-05-16";
    src = fetchgit {
      url = "git://github.com/godlygeek/tabular";
      rev = "60f25648814f0695eeb6c1040d97adca93c4e0bb";
      sha256 = "28c860ad621587f2c3213fae47d1a3997746527c17d51e9ab94c209eb7bfeb0f";
    };
    dependencies = [];

  };
  "Tagbar" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tagbar-2015-03-17";
    src = fetchgit {
      url = "git://github.com/majutsushi/tagbar";
      rev = "3634e7ab4feeab8ad49166e9e716638c20f1637c";
      sha256 = "cecbb15e025b300f688a7a67cc886a2e8a8afaf3e8fdca4a4d8ba73dabda8ab2";
    };
    dependencies = [];

  };
  "The_NERD_Commenter" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_Commenter-2014-07-08";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdcommenter";
      rev = "6549cfde45339bd4f711504196ff3e8b766ef5e6";
      sha256 = "ef270ae5617237d68b3d618068e758af8ffd8d3ba27a3799149f7a106cfd178e";
    };
    dependencies = [];

  };
  "The_NERD_tree" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_tree-2014-11-20";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdtree";
      rev = "3b98a7fcae8f9fff356907171f0406ff8cd28921";
      sha256 = "deec2ce33249829ae3925478d7d1925ea99e20c37dcc86db7c3bfac4fdc706e0";
    };
    dependencies = [];

  };
  "UltiSnips" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "UltiSnips-2015-03-05";
    src = fetchgit {
      url = "git://github.com/sirver/ultisnips";
      rev = "1971030b506a8f0e2e0398fb166f21a5341f8c7a";
      sha256 = "84c07f73ea22a34422c843c5ccb40aa8d3967175ff38ab6155303ba3c039e859";
    };
    dependencies = [];

  };
  "VimOutliner" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "VimOutliner-2015-01-09";
    src = fetchgit {
      url = "git://github.com/vimoutliner/vimoutliner";
      rev = "7c995f973c54b0d026137615af28059890edb197";
      sha256 = "9d1526ec99904fd2ccfdb4dd6763b4cd04048cb74bb7a0a4c9b4a7b1f5d75cb5";
    };
    dependencies = [];

  };
  "WebAPI" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "WebAPI-2014-10-27";
    src = fetchgit {
      url = "git://github.com/mattn/webapi-vim";
      rev = "a7789abffe936db56e3152e23733847f94755753";
      sha256 = "455b84d9fd13200ff5ced5d796075f434a7fb9c00f506769174579266ae2be80";
    };
    dependencies = [];

  };
  "YankRing" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YankRing";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=20842";
      name = "yankring_180.zip";
      sha256 = "0bsq4pxagy12jqxzs7gcf25k5ahwif13ayb9k8clyhm0jjdkf0la";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=1234";
    };


  };
  "commentary" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "commentary-2014-11-10";
    src = fetchgit {
      url = "git://github.com/tpope/vim-commentary";
      rev = "9c685131a5facfa0d643feca3a61b41c007d8170";
      sha256 = "2a9f394d0669429469c2f1ddaf9a722c2773f35da08ea9496d3b4b4e85b6038d";
    };
    dependencies = [];

  };
  "ctrlp" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-2013-07-29";
    src = fetchgit {
      url = "git://github.com/kien/ctrlp.vim";
      rev = "b5d3fe66a58a13d2ff8b6391f4387608496a030f";
      sha256 = "41f7884973770552395b96f8693da70999dc815462d4018c560d3ff6be462e76";
    };
    dependencies = [];

  };
  "extradite" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "extradite-2015-01-26";
    src = fetchgit {
      url = "git://github.com/int3/vim-extradite";
      rev = "a1dc4b63befd5032e65a0c94e7257d4636aa6a3f";
      sha256 = "94e05bbe36c9d4cee9832530531eedff0da509d5a0a52beee4e524fd4ad96714";
    };
    dependencies = [];

  };
  "fugitive" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fugitive-2015-02-20";
    src = fetchgit {
      url = "git://github.com/tpope/vim-fugitive";
      rev = "0095769029709b531d2505ee6ad9907dd9bd72a0";
      sha256 = "83184b527538d0aac01783074ec29addfa18b62880ec8959dae6e404c6ff3d11";
    };
    dependencies = [];

  };
  "ghcmod" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ghcmod-2015-03-17";
    src = fetchgit {
      url = "git://github.com/eagletmt/ghcmod-vim";
      rev = "7e5f6102aa709244f5d4cedec807eac4b901c4cb";
      sha256 = "47c5f5c4bf73dca653550b460306fa3808d864a685903bdb95ba07a6e1cd2899";
    };
    dependencies = [];

  };
  "github:JagaJaga/vim-addon-vim2nix" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "github-JagaJaga-vim-addon-vim2nix-2015-03-06";
    src = fetchgit {
      url = "git://github.com/JagaJaga/vim-addon-vim2nix";
      rev = "343d8a4e43a5b40f134e73be7140f754ca74d2e5";
      sha256 = "466ac56d4397d964cf21a63d31f2628fdea40bc94a54018affe8717de8514564";
    };
    dependencies = ["vim-addon-manager"];

  };
  "matchit.zip" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "matchit.zip";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=8196";
      name = "matchit.zip";
      sha256 = "1bbm8j1bhb70kagwdimwy9vcvlrz9ax5bk2a7wrmn4cy87f9xj4l";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=39";
    };

  unpackPhase = ''
    (
     sourceRoot=d
     mkdir $sourceRoot; cd $sourceRoot;
     unzip $src
    )
  '';
  };
  "pathogen" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "pathogen-2014-11-06";
    src = fetchgit {
      url = "git://github.com/tpope/vim-pathogen";
      rev = "b9fb0dfd811004010f5f6903edef42d6004ebea2";
      sha256 = "62ec7e9721651aa86aa716d47c2057771f7d093f414c3b98f50a759d210db4c7";
    };
    dependencies = [];

  };
  "quickfixstatus" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "quickfixstatus-2011-09-02";
    src = fetchgit {
      url = "git://github.com/dannyob/quickfixstatus";
      rev = "fd3875b914fc51bbefefa8c4995588c088163053";
      sha256 = "7b6831d5da1c23d95f3158c67e4376d32c2f62ab2e30d02d3f3e14dcfd867d9b";
    };
    dependencies = [];

  };
  "rainbow_parentheses" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow_parentheses-2013-03-04";
    src = fetchgit {
      url = "git://github.com/kien/rainbow_parentheses.vim";
      rev = "eb8baa5428bde10ecc1cb14eed1d6e16f5f24695";
      sha256 = "47975a426d06f41811882691d8a51f32bc72f590477ed52b298660486b2488e3";
    };
    dependencies = [];

  };
  "rust" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rust-2015-01-29";
    src = fetchgit {
      url = "git://github.com/wting/rust.vim";
      rev = "2450ecf3091cc7c2711ca9f00eae8e3bedd04376";
      sha256 = "9d2e8b2c06d6100f9a1e76644313d457a2ff955241d8f712de6fddd0b7f5c4ee";
    };
    dependencies = [];

  };
  "sensible" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sensible-2014-11-24";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sensible";
      rev = "b30dcf387af977acfa21732592bfca05598b2188";
      sha256 = "6a9fc68c3eb0ee500ac59bdbc2c48d98e88a2936ee544f7203fa1a0296002b5f";
    };
    dependencies = [];

  };
  "snipmate" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "snipmate-2015-03-21";
    src = fetchgit {
      url = "git://github.com/garbas/vim-snipmate";
      rev = "2079ea5aadaada568f78acfc6b565945625ed97d";
      sha256 = "47f5d131485f8a57389a0b455c6e83f8f543d71a04cbaa7af594b3abe9099d9f";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };
  "sourcemap" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sourcemap-2012-09-19";
    src = fetchgit {
      url = "git://github.com/chikatoike/sourcemap.vim";
      rev = "0dd82d40faea2fdb0771067f46c01deb41610ba1";
      sha256 = "a08c77aea39be4a0a980d62673d1d17fecc518a8aeb9101210e453aaacb78fbd";
    };
    dependencies = [];

  };
  "surround" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "surround-2015-03-15";
    src = fetchgit {
      url = "git://github.com/tpope/vim-surround";
      rev = "772ab9587b7d1e2c3bae75395c9123803059ba8a";
      sha256 = "5f4c5afecaa99dc67875a2356b46cb6e8daeffca4a00a451965ca022de26cbef";
    };
    dependencies = [];

  };
  "table-mode" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "table-mode-2015-03-17";
    src = fetchgit {
      url = "git://github.com/dhruvasagar/vim-table-mode";
      rev = "c0a6d43f2191b841c01cec0638a33a8116f7f920";
      sha256 = "222532a9803f855b5f261eb311359980625606716c1b9419703b97874554c49d";
    };
    dependencies = [];

  };
  "tlib" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tlib-2015-02-23";
    src = fetchgit {
      url = "git://github.com/tomtom/tlib_vim";
      rev = "2376d1233e7d1db8157fdc3157278dda7a2c796f";
      sha256 = "07966a0f2a073ae07e8d2a63a8a265ec0053997721545b41cedff910bcc24de0";
    };
    dependencies = [];

  };
  "undotree" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "undotree-2015-03-01";
    src = fetchgit {
      url = "git://github.com/mbbill/undotree";
      rev = "fa018f38252f58073f2987f8bf0d2d4a61e07277";
      sha256 = "c52874b0b85d0a44a1f2f055a74985886af97615bac032259fc21d6ea40d6ca7";
    };
    dependencies = [];

  };
  "vim-addon-actions" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-actions-2014-09-22";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-actions";
      rev = "a5d20500fb8812958540cf17862bd73e7af64936";
      sha256 = "d2c3eb7a1f29e7233c6fcf3b02d07efebe8252d404ee593419ad399a5fdf6383";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };
  "vim-addon-async" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-async-2013-10-18";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-async";
      rev = "dadc96e188f1cdacbac62129eb29a1eacfed792c";
      sha256 = "27f941e21a8ca5940bd20914e2a9e3809e554f3ef2c27b3bafb9a153107a5d07";
    };
    dependencies = ["vim-addon-signs"];

  };
  "vim-addon-background-cmd" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-background-cmd-2015-01-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-background-cmd";
      rev = "e99076519139b959edce0581b0f31207a5ec7c64";
      sha256 = "524795221ae727635fe52ead47dff452d2dd48900917da609426ea399a2eceeb";
    };
    dependencies = ["vim-addon-mw-utils"];

  };
  "vim-addon-commenting" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-commenting-2013-06-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-commenting";
      rev = "b7cf748ac1c9bf555cbd347589e3b7196030d20b";
      sha256 = "4ad7d5f6669f0a1b4a24c9ce3649c030d7d3fc8588de4d4d6c3269140fbe9b3e";
    };
    dependencies = [];

  };
  "vim-addon-completion" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-completion-2015-02-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-completion";
      rev = "021c449a5ce1ce4ac0af5955e05b0279c1cc0e75";
      sha256 = "969a474749edf7e4443d2540eaf12e891cc0a3f5533e62e081d32408f403a0ea";
    };
    dependencies = ["tlib"];

  };
  "vim-addon-errorformats" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-errorformats-2014-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-errorformats";
      rev = "dcbb203ad5f56e47e75fdee35bc92e2ba69e1d28";
      sha256 = "a1260206545d5ae17f2e6b3319f5cf1808b74e792979b1c6667d75974cc53f95";
    };
    dependencies = [];

  };
  "vim-addon-goto-thing-at-cursor" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-goto-thing-at-cursor-2012-01-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-goto-thing-at-cursor";
      rev = "f052e094bdb351829bf72ae3435af9042e09a6e4";
      sha256 = "34658ac99d9a630db9c544b3dfcd2c3df69afa5209e27558cc022b7afc2078ea";
    };
    dependencies = ["tlib"];

  };
  "vim-addon-local-vimrc" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-local-vimrc-2015-03-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-local-vimrc";
      rev = "6a27f95b35befa70cd0d049329cd0920566c764b";
      sha256 = "f0687e08f380ff085b6fa3e708d1631049571706f55d796e22612aff02e51459";
    };
    dependencies = [];

  };
  "vim-addon-manager" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-manager-2014-12-03";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-manager";
      rev = "fda9d2f4522024aa8bd8b8305e6a71c4a4a28c07";
      sha256 = "a3b5da9bcc01c6f0fb0a5e13a6f9efb58471339ed32c480fde96856bb9e1e7be";
    };
    dependencies = [];

  };
  "vim-addon-mru" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mru-2013-08-08";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mru";
      rev = "e41e39bd9d1bf78ccfd8d5e1bc05ae5e1026c2bb";
      sha256 = "15b70f796f28cbd999060fea7f47408fa8a6cb176cd4915b9cc3dc6c53eed960";
    };
    dependencies = ["vim-addon-other" "vim-addon-mw-utils"];

  };
  "vim-addon-mw-utils" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mw-utils-2012-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mw-utils";
      rev = "0c5612fa31ee434ba055e21c76f456244b3b5109";
      sha256 = "4e1b6d1b59050f1063e58ef4bee9e9603616ad184cd9ef7466d0ec3d8e22b91c";
    };
    dependencies = [];

  };
  "vim-addon-nix" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-nix-2015-03-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-nix";
      rev = "2aed79ba5d8c5e6abd102de77e55e242f61b17f1";
      sha256 = "0e326e2c6cb6597ca533a64a845ef9dd946cd249250375ef9775d974ecef37e2";
    };
    dependencies = ["vim-addon-completion" "vim-addon-goto-thing-at-cursor" "vim-addon-errorformats" "vim-addon-actions" "vim-addon-mw-utils" "tlib"];

  };
  "vim-addon-other" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-other-2014-07-15";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-other";
      rev = "f78720c9cb5bf871cabb13c7cbf94378dbf0163b";
      sha256 = "43f027e4b7576031072515c23c2b09f7f2c8bba7ee43a1e2041a4371bd954d1b";
    };
    dependencies = ["vim-addon-actions" "vim-addon-mw-utils"];

  };
  "vim-addon-php-manual" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-php-manual-2015-01-01";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-php-manual";
      rev = "5f9810dd1f6e9f36a45f637ae6260ccff09256ff";
      sha256 = "3942eb6a7191c308beab240e91c99ee4e2c52e2d672503d46f98312e823b86cd";
    };
    dependencies = [];

  };
  "vim-addon-signs" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-signs-2013-04-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-signs";
      rev = "17a49f293d18174ff09d1bfff5ba86e8eee8e8ae";
      sha256 = "a9c03a32e758d51106741605188cb7f00db314c73a26cae75c0c9843509a8fb8";
    };
    dependencies = [];

  };
  "vim-addon-sql" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-sql-2014-01-18";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-sql";
      rev = "05b8a0c211f1ae4c515c64e91dec555cdf20d90b";
      sha256 = "a1334ae694e0a03229bacc8ba7e08e7223df240244c7378e3f1bd91d74e957c2";
    };
    dependencies = ["vim-addon-completion" "vim-addon-background-cmd" "tlib"];

  };
  "vim-addon-syntax-checker" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-syntax-checker-2013-07-12";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-syntax-checker";
      rev = "8eb7217e636ca717d4de5cd03cc0180c5b66ae77";
      sha256 = "aef048e664653b5007df71ac24ed34ec55d8938c763d3f80885a122e445a9b3d";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };
  "vim-addon-toggle-buffer" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-toggle-buffer-2012-01-13";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-toggle-buffer";
      rev = "a1b38b9c5709cba666ed2d84ef06548f675c6b0b";
      sha256 = "672166ecfe0599177afb56b444366f587f77e9659c256ac4e41ee45cb2df6055";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };
  "vim-addon-xdebug" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-xdebug-2014-08-29";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-xdebug";
      rev = "45f26407305b4ce6f8f5f37d2b5e6e4354104172";
      sha256 = "0a7bf2caf36772c94bd25bfbf46bf628623809c9cfab447ff788eb74149464ef";
    };
    dependencies = ["WebAPI" "vim-addon-mw-utils" "vim-addon-signs" "vim-addon-async"];

  };
  "vim-airline" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-2015-03-24";
    src = fetchgit {
      url = "git://github.com/bling/vim-airline";
      rev = "f45ecdac15d99ed2354873a8b4d40432fd0a85a3";
      sha256 = "30176b06f13838fe7b0374e2ed529c0d26abe432ff7453c7443b2f204cf70012";
    };
    dependencies = [];

  };
  "vim-coffee-script" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-coffee-script-2014-10-10";
    src = fetchgit {
      url = "git://github.com/kchmck/vim-coffee-script";
      rev = "827e4a38b07479433b619091469a7495a392df8a";
      sha256 = "89ee4c7cce9f3310be502df6b2dd2e70a715c0b06882afc9c8169fbf58b207d0";
    };
    dependencies = [];

  };
  "vim-easy-align" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easy-align-2014-12-14";
    src = fetchgit {
      url = "git://github.com/junegunn/vim-easy-align";
      rev = "c62d124be614de65922b15d468c4049d1eee9353";
      sha256 = "868bd5a0405a7611e020fe7692a078ca72562674b6d9a404d2d83f665af96aee";
    };
    dependencies = [];

  };
  "vim-gitgutter" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gitgutter-2015-03-23";
    src = fetchgit {
      url = "git://github.com/airblade/vim-gitgutter";
      rev = "8345c35770ffc6fc4088c36406d1e24170aabcc6";
      sha256 = "f7580832ebfd60f0b7cf05e697ac44e4b59a0f606fe49b7ef392052a50c69ad3";
    };
    dependencies = [];

  };
  "vim-iced-coffee-script" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-iced-coffee-script-2013-12-27";
    src = fetchgit {
      url = "git://github.com/noc7c9/vim-iced-coffee-script";
      rev = "e42e0775fa4b1f8840c55cd36ac3d1cedbc1dea2";
      sha256 = "c7859591975a51a1736f99a433d7ca3e7638b417340a0472a63995e16d8ece93";
    };
    dependencies = [];

  };
  "vim-latex-live-preview" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-latex-live-preview-2013-11-25";
    src = fetchgit {
      url = "git://github.com/xuhdev/vim-latex-live-preview";
      rev = "18625ceca4de5984f3df50cdd0202fc13eb9e37c";
      sha256 = "261852d3830189a50176f997a4c6b4ec7e25893c5b7842a3eb57eb7771158722";
    };
    dependencies = [];

  };
  "vim-signature" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signature-2015-01-12";
    src = fetchgit {
      url = "git://github.com/kshenoy/vim-signature";
      rev = "b4ac4f38528313456f98b1a50722cfc9a06bfc45";
      sha256 = "c065eb81669fd76a8bf6d19e220c85ad07ede73e6a9b3dd12634611146303675";
    };
    dependencies = [];

  };
  "vim-gista" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gista-2015-01-29";
    src = fetchgit {
      url = "git://github.com/lambdalisue/vim-gista";
      rev = "e450417a6eaeb99d3982b880507697dce85b7217";
      sha256 = "a7665dbc63a35d1fe9b7679a498deafb80c8dfb05fced37ac4722212c673f2ec";
    };
    dependencies = [];

  };
  "vim-snippets" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-snippets-2015-03-24";
    src = fetchgit {
      url = "git://github.com/honza/vim-snippets";
      rev = "707f005ccddaa15a0b8c207a7a711b0a9590578a";
      sha256 = "0c5807b82e18530a6b83f4f1c0010564a1a4b39f687672ab235b95e694095d03";
    };
    dependencies = [];

  };
  "vim2hs" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim2hs-2014-04-16";
    src = fetchgit {
      url = "git://github.com/dag/vim2hs";
      rev = "f2afd55704bfe0a2d66e6b270d247e9b8a7b1664";
      sha256 = "485fc58595bb4e50f2239bec5a4cbb0d8f5662aa3f744e42c110cd1d66b7e5b0";
    };
    dependencies = [];

  };
  "vundle" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vundle-2015-03-21";
    src = fetchgit {
      url = "git://github.com/gmarik/vundle";
      rev = "cfd3b2d388a8c2e9903d7a9d80a65539aabfe933";
      sha256 = "7ce9bb0a59c8f86cedd9b3867b834bcd160f2224c187189997ef76c2bfd99d50";
    };
    dependencies = [];

  };
  "wombat256" = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "wombat256";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=13400";
      name = "wombat256mod.vim";
      sha256 = "1san0jg9sfm6chhnr1wc5nhczlp11ibca0v7i4gf68h9ick9mysn";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=2465";
    };

  };

}
